@@ -9,7 +9,7 @@
 #
 package Config::Model::Tester;
 # ABSTRACT: Test framework for Config::Model
-$Config::Model::Tester::VERSION = '2.056';
+$Config::Model::Tester::VERSION = '2.058';
 use warnings;
 use strict;
 use locale;
@@ -52,7 +52,7 @@ sub setup_test {
     $wr_root->remove_tree();
     $wr_root->mkpath( { mode => 0755 } );
 
-    $conf_dir =~ s!~/!$home_for_test/! if $conf_dir;
+    $conf_dir =~ s!~/!$home_for_test/! if $conf_dir and $home_for_test;
 
     my $wr_dir    = $wr_root->child('test-' . $t_name);
     my $wr_dir2   = $wr_root->child('test-' . $t_name.'-w');
@@ -74,7 +74,7 @@ sub setup_test {
             if (not defined $destination_str) {
                 die "$app_to_test $t_name setup error: cannot find destination for test file $file" ;
             }
-            $destination_str =~ s!~/!$home_for_test/!;
+            $destination_str =~ s!~/!$home_for_test/! if $home_for_test;
             my $destination = $wr_dir->child($destination_str) ;
             $destination->parent->mkpath( { mode => 0755 }) ;
             my $data_file = $ex_data->child($file);
@@ -398,7 +398,7 @@ sub run_model_test {
 
     note("Beginning $app_to_test test ($app_to_test_conf)");
 
-    unless ( my $return = do $app_to_test_conf ) {
+    unless ( my $return = do "./$app_to_test_conf" ) {
         warn "couldn't parse $app_to_test_conf: $@" if $@;
         warn "couldn't do $app_to_test_conf: $!" unless defined $return;
         warn "couldn't run $app_to_test_conf" unless $return;
@@ -572,7 +572,7 @@ Config::Model::Tester - Test framework for Config::Model
 
 =head1 VERSION
 
-version 2.056
+version 2.058
 
 =head1 SYNOPSIS
 
@@ -1151,7 +1151,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Config-Model-Tester>
+L<http://cpants.cpanauthors.org/dist/Config-Model-Tester>
 
 =item *
 
